# Setup
from memestatus import core
from math import floor

# Disk used (in GB)
def disk_used():
    return floor(apires['disk_used'])
# Total space (in GB)
def disk_total():
    return floor(apires['disk_total'])
# Disk used (in percentage)
def disk_percent():
    return floor(apires['disk_percent'])



# Setup
from memestatus import core
from math import floor

# Memory used (in percentage)
def mem_percent():
    return floor(apires['mem_percent'])
# Memory free (in bytes6)
def mem_free():
    return apires['mem_free']
# Total RAM
def mem_total():
    return apires['mem_max']




# Setup
import requests

statusendpoint = 'http://status.memework.org/api'

# Core magic
# Uses requests to get API data,
apiget = requests.get(statusendpoint)
# then uses the JSON function to get JSON.
apires = apiget.json()



from distutils.core import setup
setup(
  name = 'memestatus',
  packages = ['memestatus'], # this must be the same as the name above
  version = '1.0',
  description = 'A library for parsing status.memework.org',
  author = 'S Stewart',
  author_email = 'iamtheworst@programmer.net',
  url = 'https://git.memework.org/lold/memestatus', # use the URL to the github repo
  download_url = 'https://git.memework.org/lold/memestatus/archive/1.0.tar.gz', # I'll explain this in a second
  keywords = ['forfun', 'memework', 'parsing'], # arbitrary keywords
  classifiers = [],
)
